@@ -164,11 +164,9 @@ class Queue(object):
             while self.putters:
                 putter = self.putters.pop()
                 if putter:
-                    # obtain the item directly from putter bypassing the queue
-                    item = putter.item
-                    putter.item = _NONE
                     putter.switch(putter)
-                    return item
+                    if self.qsize():
+                        return self._get()
             raise Empty
         elif block:
             waiter = Waiter()
@@ -209,9 +207,10 @@ class Queue(object):
                     if putter:
                         getter = self.getters.pop()
                         if getter:
-                            # deliver the item from putter to getter bypassing the queue
                             item = putter.item
-                            putter.item = _NONE
+                            putter.item = _NONE # this makes greenlet calling put() not to call _put() again
+                            self._put(item)
+                            item = self._get()
                             getter.switch(item)
                             putter.switch(putter)
                         else:
@@ -285,8 +284,8 @@ class JoinableQueue(Queue):
             result += ' tasks=%s _cond=%s' % (self.unfinished_tasks, self._cond)
         return result
 
-    def put(self, item, block=True, timeout=None):
-        Queue.put(self, item, block, timeout)
+    def _put(self, item):
+        Queue._put(self, item)
         self.unfinished_tasks += 1
         self._cond.clear()
 
