@@ -35,7 +35,10 @@ error = _socket.error
 timeout = _socket.timeout
 __socket__ = __import__('socket')
 _fileobject = __socket__._fileobject
-sslerror = __socket__.sslerror
+try:
+    sslerror = __socket__.sslerror
+except AttributeError:
+    pass
 gaierror = __socket__.gaierror
 
 import sys
@@ -269,8 +272,7 @@ class socket(object):
     def recv(self, *args):
         if self.timeout!=0.0:
             wait_read(self.fileno(), timeout=self.timeout, timeout_exc=timeout)
-        res = self.fd.recv(*args)
-        return res
+        return self.fd.recv(*args)
 
     def recvfrom(self, *args):
         if self.timeout!=0.0:
