@@ -151,7 +151,7 @@ class TestUnlink(greentest.TestCase):
         assert len(p._links)==1, p._links
         p.unlink(getcurrent())
         assert not p._links, p._links
-        
+
         g = gevent.Greenlet()
         link(g)
         assert len(p._links)==1, p._links
@@ -475,7 +475,7 @@ class A(object):
     def method(self):
         pass
 
-hexobj = re.compile('0x[0123456789abcdef]+')
+hexobj = re.compile('0x[0123456789abcdef]+L?')
 
 class TestStr(greentest.TestCase):
 
