@@ -4,7 +4,7 @@ from gevent import monkey
 monkey.patch_all()
 
 import greentest
-from greentest import test_support
+import test_support
 
 import socket
 import select
